/* ------------------------------------------------------------------------ */
/*                                                                          */
/*  Copyright (C)                                                           */
/*                                                                          */
/*  This program is free software; you can redistribute it and/or modify    */
/*  it under the terms of the GNU General Public License as published by    */
/*  the Free Software Foundation; either version 2 of the License, or       */
/*  (at your option) any later version.                                     */
/*                                                                          */
/*  This program is distributed in the hope that it will be useful, but     */
/*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANT-    */
/*  ABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General        */
/*  Public License for more details.                                        */
/*                                                                          */
/*  You should have received a copy of the GNU General Public License along */
/*  with this program; if not, write to the Free Software Foundation, Inc., */
/*  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA                   */
/*                                                                          */
/* ------------------------------------------------------------------------ */
/*  $Author: vogje02 $ $Revision: 1.3 $ $Date: 2002/07/09 19:36:30 $      */
/* ------------------------------------------------------------------------ */

#include "listener.h"

/**
 * This implements the nmap listener. 
 *
 * It listens to the other end of the pipe opened by the nmap start process
 * and displays the incoming messages in the output window.
 */
CListener::CListener( CEdit* e, CButton* sa, CButton* so, CEdit* l, 
					  HANDLE p, CEdit* s, CStatic* b ) : Thread( NULL, 0, 0 )
{
	currItem = 0;

	pipe = p;
	m_status = s;
	m_start = sa;
	m_stop = so;
	m_loglist = l;
	m_hostedit = e;
	m_busyicon = b;

	LOGFONT logfont;
	m_loglist->GetFont()->GetLogFont( &logfont) ;

	lstrcpy( logfont.lfFaceName, (TCHAR*)"Lucida Console" );

	CFont* font = new CFont();
	font->CreateFontIndirect( &logfont );

	m_loglist->SetFont( font, false );
	CDC* pDC = m_loglist->GetWindowDC();
	pDC->SetTextColor(RGB(0, 255, 0));
    pDC->SetBkColor(RGB(255, 255, 255));


	// 500k output buffer
	buffer = (char*)malloc( 500*1024 );
}

/////////////////////////////////////////////////////////////////////////////
// Insert a row into the selection list
void CListener::InsertLogItem( char* text ) 
{
	*buffer = '\0';
	m_loglist->GetWindowText( buffer, m_loglist->GetWindowTextLength() + 1 );
	strcat( buffer, "\r\n" );
	strcat( buffer, text );
	m_loglist->SetWindowText( buffer );
	m_loglist->LineScroll( m_loglist->GetLineCount() );
}

int CListener::ReadFromPipe( char *buf, int bufsz ) 
{
	DWORD count;

	// Apparently the pipe is available for		
	// reading -- Read up to # of bytes in buffer */
	if( !ReadFile( pipe, buf, bufsz, &count, NULL ) )  {
			
		if( (GetLastError() == ERROR_HANDLE_EOF || count == 0) && m_status->m_hWnd  )
			m_status->SendMessage( SB_SETTEXT, 0, (LPARAM)"NMap process finished!" ); 
	}
	*( buf + count ) = '\0';

	return strlen( buf );
}

/**
 * Disables the start and enables the stop buttons.
 */
void CListener::SetBusy()
{
	// Change the enable of the start/stop buttons
	m_start->EnableWindow( FALSE );
	m_stop->EnableWindow( TRUE );
}

/**
 * Endless loop which reads the pipe.
 */
void CListener::Run()
{
	int count;
	char buf[500*1024], *token;
	
	*buf = '\0';

	// Clear the list
	m_loglist->SetWindowText( "" );
	
	SetBusy();

	while( ( count = ReadFromPipe( buf, sizeof(buf) ) ) > 0) {

		buf[count] = '\0';
		char tmp[20];
		sprintf( tmp, "Count: %d", count);
		m_status->SendMessage( SB_SETTEXT, 0, (LPARAM)tmp ); 

		token = strtok( buf, "\r\n" );
		if( token ) {
			do {
				InsertLogItem( token );
			} while( ( token = strtok( NULL, "\r\n" ) ) );
		}
	}

	// Enable all host windows and the scan buttons
	m_start->EnableWindow( TRUE );
	m_stop->EnableWindow( FALSE );
	m_hostedit->EnableWindow( TRUE );

	// Set the non-busy icon in the status bar
	CNmapwinApp* pApp= (CNmapwinApp*) AfxGetApp();
	m_busyicon->SetIcon( pApp->LoadIcon( IDI_ICON1 ) );
	m_busyicon->RedrawWindow(NULL, NULL, RDW_UPDATENOW );

	return;
}
